@@ -55,3 +55,13 @@ trydefault <- function(expr, default, quiet = FALSE){
   }
   result
 }
+
+assert <- function(x, y) {
+  if (!is.null(x)) {
+    if (!class(x) %in% y) {
+      stop(deparse(substitute(x)), " must be of class ",
+           paste0(y, collapse = ", "), call. = FALSE)
+    }
+  }
+}
+
